globals [
  avg-speed avg-energy            ;; current averages
  avg-speed-init avg-energy-init  ;; initial averages
  clock vsplit vclock             ;; clock variables
  box-edge                        ;; patch coords of box's edge
  initspeed initmass              ;; initial particle settings
  pressure
  switch-now?
  pressure-history
]

turtles-own [
  speed mass energy new-speed           ;; turtle info
  v1t v1l tmp-turtle                    ;; collision info (turtle 1)
  heading2 mass2 speed2 v2t v2l turtle2 ;; collision info (turtle 2)
  theta momentum                        ;; collision info (both turtles)
]

to setup
  ca
  set initspeed 10.0
  set initmass 1.0
  set box-edge (screen-edge-x - 1)
  make-box
  cct initial-particles
  [
    set new-speed initspeed
    set mass initmass
    random-position
    rt random 360
    set shape "circle"
    set momentum 0
    recolor
  ]
  set clock  0
  set vclock  0
  set pressure-history []
  update-variables
  set avg-speed-init avg-speed
  set avg-energy-init avg-energy
  setup-plots
  do-plotting
end

;; updates energy and speed of particles and pressure of the 
;; system after every time tick
to update-variables
  ask turtles
    [ set speed new-speed
      set energy (0.5 * speed * speed * mass) ]
  ifelse any turtles
  [
    set avg-speed  mean values-from turtles [speed ]
    set avg-energy mean values-from turtles [energy]
    set pressure sum values-from turtles [momentum]
    calculate-pressure
    set vsplit (round ((max values-from turtles [speed]) * 1.2))
  ]
  [ set vsplit initspeed ]
end

;; number of collisions particles have with the walls calculates pressure.
to calculate-pressure
  ifelse length pressure-history < scale
  [ set pressure-history fput pressure pressure-history ]
  [ set pressure-history fput pressure (but-last pressure-history) ]
end

;;procedure for the button release particles
to release-particles [n]
  while [n > 0]
  [ ifelse not any turtles-at (1 - box-edge) 0
    [ cct 1
      [ set new-speed initspeed
        set mass initmass
        set xcor 0 - box-edge
        rt 45 + random 90
        set shape "circle"
        set momentum 0
        recolor
      ]
      set n n - 1
    ]
    [ set switch-now? true ]
  ]
end

;; runs the model
to go
  ask turtles [ bounce ]
  ask turtles [ move ]
  set vclock (vclock + 1)
  if (vclock = vsplit)
  [ set clock  (clock + 1)
    set vclock 0
    update-variables
    do-plotting
    ask turtles [ set momentum 0 ]
  ]
end

;; turtle procedure to bounce off the walls and to keep 
;; particles within the box.
to bounce 
  locals [ new-px new-py ]
  ; if we're not about to hit a wall (yellow patch),
  ; we don't need to do any further checks
  if not shade-of? pcolor-of patch-at dx dy yellow [ stop ]
  ; get the coordinates of the patch we'll be on if we go forward 1
  set new-px round (xcor + dx)
  set new-py round (ycor + dy)
  ; check: hitting left or right wall?
  if (abs new-px = box-edge)
    ; if so, reflect heading around x axis
    [ set heading (0 - heading) 
      set momentum momentum + abs (sin heading * mass * speed)
    ]
  ; check: hitting top or bottom wall?
  if (abs new-py = box-edge)
    ; if so, reflect heading around y axis
    [ set heading (180 - heading) 
      set momentum momentum + abs (cos heading * mass * speed)
    ]
end

;; moves turtles round within the box
to move  
  jump ( speed / vsplit )
  check-for-collision
end

;;turtle procedure to check for collisions with other particles/turtles
to check-for-collision 
  if count other-turtles-here = 1
    [ set tmp-turtle random-one-of other-turtles-here
      if ((who > who-of tmp-turtle) and (turtle2 != tmp-turtle))
        [ collide ]
    ]
end

;; turtle collision code
to collide  
  get-turtle2-info
  calculate-velocity-components
  set-new-speed-and-headings
end

;; turtle procedure on getting info (mass and speed)
;; of the other turtle it is colliding with
to get-turtle2-info  
  set turtle2 tmp-turtle
  set mass2 mass-of turtle2
  set speed2 new-speed-of turtle2
  set heading2 heading-of turtle2
end

;; calculate turtle's new speed, heading and energy after a collision
to calculate-velocity-components
  locals [ vcm ]  ;; CM vel. along dir. theta
  set theta (random 360)
  set v1l (new-speed * sin (theta - heading))
  set v1t (new-speed * cos (theta - heading))
  set v2l (speed2 * sin (theta - heading2))
  set v2t (speed2 * cos (theta - heading2))
  set vcm (((mass * v1t) + (mass2 * v2t)) / (mass + mass2) )
  set v1t (vcm + vcm - v1t)
  set v2t (vcm + vcm - v2t)
end

to set-new-speed-and-headings  
  set new-speed sqrt ((v1t * v1t) + (v1l * v1l))
  set heading (theta - (atan v1l v1t)) 
  
  set new-speed-of turtle2 sqrt ((v2t * v2t) + (v2l * v2l))
  set heading-of turtle2 (theta - (atan v2l v2t)) 
  
  recolor
  ask turtle2 [ recolor ]
end

to recolor
  ifelse new-speed < (0.5 * initspeed)
    [ set color blue ]
    [ ifelse new-speed > (1.5 * initspeed)
        [ set color red ]
        [ set color green ] ]
end

;; patch code to build a box
to make-box
  ask patches with [ ((abs pxcor = box-edge) and (abs pycor <= box-edge)) or
                     ((abs pycor = box-edge) and (abs pxcor <= box-edge)) ]
    [ set pcolor yellow ]
  ask patches with [ pycor = 0 and pxcor < (1 - box-edge) ]
  [
    set pcolor yellow - 5  ;; trick the bounce code so particles don't go into the inlet.
    set pcolor-of patch-at 0  1 yellow
    set pcolor-of patch-at 0 -1 yellow
  ]
end

to random-position
  setxy ((1 - box-edge) + random ((2 * box-edge) - 2))
        ((1 - box-edge) + random ((2 * box-edge) - 2))
end

;;; plotting procedures

to setup-plots
  set-current-plot "Particle Count vs. Time"
  set-plot-y-range 0 initial-particles + 1
end

to do-plotting
  set-current-plot "Particle Count vs. Time"
  plot count turtles
  
  set-current-plot "Pressure vs. Time"
  plot mean pressure-history
end

; *** NetLogo Model Copyright Notice ***
;
; This activity and associated models and materials were created as part of the project:
; MODELING ACROSS THE CURRICULUM.  The project gratefully acknowledges the support of the 
; National Science Foundation, National Institute of Health and the Department of Education 
; (IERI program) -- grant number REC # 0115699. Additional support was provided through the 
; project: PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN CLASSROOMS 
; -- NSF (REPP program) -- grant number REC #9814682.
;
; Copyright 2002 by Uri Wilensky.  Updated 2003.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2002).  NetLogo CC Pressure 2 model.
; http://ccl.northwestern.edu/netlogo/models/CCPressure2.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
262
10
556
325
35
35
4.0
1
10
0
0

CC-WINDOW
329
387
535
554
Command Center

MONITOR
262
329
320
378
clock
clock
0
1

MONITOR
329
329
413
378
avg-speed
avg-speed
0
1

BUTTON
10
53
98
86
go
go
T
1
T
OBSERVER

BUTTON
10
10
98
43
NIL
setup
NIL
1
T
OBSERVER

PLOT
9
370
254
547
Particle Count vs. Time
time
count
0.0
20.0
0.0
200.0
true
false

MONITOR
422
329
505
378
avg-energy
avg-energy
0
1

SLIDER
110
51
255
84
number
number
0
200
100
1
1
NIL

BUTTON
68
96
187
129
release-particles
release-particles number
NIL
1
T
OBSERVER

SLIDER
109
10
256
43
initial-particles
initial-particles
2
500
100
1
1
NIL

MONITOR
260
387
320
436
particles
count turtles
0
1

PLOT
9
139
254
315
Pressure vs. Time
time
pressure
0.0
20.0
0.0
100.0
true
false

MONITOR
10
319
100
368
pressure
pressure
0
1

SLIDER
104
324
252
357
scale
scale
0
10
5
1
1
clock cycles

@#$#@#$#@
Connected Chemistry Curriculum is currently under development, for more information please refer to http://ccl.northwestern.edu/curriculum/chemistry/

WHAT IS IT?
-----------
This model simulates the behavior of gas particles that are trapped in a fixed container.  The model is specifically looking at how a number of particles affect the pressure of this system.  The independent variables within this model are the number of initial particles and the amount of particles added while the simulation is running.  Adding a spurt of particles into the container increases the number of particles that are moving and colliding with each other and the walls.  

This model is part of the Connected Chemistry High School Curriculum and is the second model in a series that explores the concept of pressure.  In this model, students look at the relationship between number of particles and pressure.  The other CC Pressure models use the same model but look at different aspects and variables within this system.  These models have been adapted from the model GasLab Pressure Box, which can be found in the Unverified section of the GasLab folder found under Chemistry and Physics.  

These pressure models are part of a suite of models that students use to gain deeper insight on Gas Laws and particle behavior. Other models in this suite include the CC Volume models and CC Heat Box models.

In all of the Connected Chemistry Curriculum models, the same basic rules are used for expressing what happens when gas particles collide.  Each model has different features in order to show different aspects of the behavior of gases.


HOW IT WORKS
------------
Particles are modeled as perfectly elastic particles with no energy except their kinetic energy -- which is due to their motion.  Collisions between particles are elastic.  Particles are colored according to speed -- blue for slow, green for medium, and red for high speeds.

The exact way two particles collide is as follows:
1. Two turtles "collide" when they find themselves on the same patch.
2. A random axis is chosen, as if they are two balls that hit each other and this axis is the line connecting their centers.
3. They exchange momentum and energy along that axis, according to the conservation of momentum and energy.  This calculation is done in the center of mass system.
4. Each turtle is assigned its new velocity, energy, and heading.
5. If a turtle finds itself on or very close to a wall of the container, it "bounces" -- that is, reflects its direction and keeps its same speed.


HOW TO USE IT
-------------
Buttons:
  SETUP - sets up the initial conditions set on the sliders.  Be sure to wait till the Setup button stops before pushing GO.
  GO - runs the code again and again.  
  RELEASE-PARTICLES - when pressed releases particles into the box while the simulation is running.

Sliders:
  INITIAL-PARTICLES - sets the number of gas particles in the box when the simulation starts.
  NUMBER - the number of gas particles released into the box when the RELEASE-PARTICLES button is pressed.
  SCALE - determines the number of clock ticks over which the different measurements are taken.

Monitors:
  CLOCK - number of clock cycles that GO has run.
  AVG-SPEED - average speed of all the particles in the box.
  AVG-ENERGY - average kinetic energy of the particles in the box.
  PARTICLES - the number of particles in the box.
  PRESSURE - the total pressure in the box.

Plots:
  PRESSURE - plots the pressure in the box over time.
  PARTICLE COUNT - plots the number of particles in the box over time.

Initially, the particles are not moving. Therefore the initial pressure is zero.  As the particles start moving, they all have the same speed in random directions.  As the particles repeatedly collide, they exchange energy and head off in new directions, and the speeds are dispersed -- some particles get faster, some get slower.


THINGS TO NOTICE
----------------
What is happening to the initial particles as a new spurt of particles enters the box? 

Can you relate what you can see happening to the particles in the box with changes in pressure?  The average speed?  The average energy?

Why does the pressure change over time, even when the number of particles is the same?  How long does it take for the pressure to stabilize?

In what ways is this model an incorrect idealization of the real world?


THINGS TO TRY
-------------
Try different settings, especially the extremes.   Are the particles behaving in a similar way?  How does this affect the pressure?  The energy?  

Can you make the pressure graph smooth?  Can you do it in more than one way? 

Sometimes, when going up in an elevator, airplane or up a mountain we feel a 'popping' sensation in our ears.  This is associated with changes in pressure.  Can you relate between this model and these changes in pressure?  Are the temperature and volume constant in this situation?


EXTENDING THE MODEL
-------------------
Add a histogram showing all the particles speeds throughout the run of the model.

Add a switch that would continuously add particles to the box?


CREDITS AND REFERENCES
----------------------
To refer to this model in academic publications, please use: Wilensky, U. (2002).  NetLogo CC Pressure 2 model.  http://ccl.northwestern.edu/netlogo/models/CCPressure2. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

circle
false
0
Circle -7566196 true true 35 35 230

@#$#@#$#@
NetLogo 1.3beta1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
