;; goat stacking/movement
;; simplify quantities (particularly bite-size)
;; add ability to get rid of goats

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Variable and Breed declarations ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals [
  day                ;; number of days so far
  clock              ;; number of times through the go cycle 
    
  grass-scale        ;; range for the amount of grass above the minimum each patch can hold 
  grass-min          ;; the minimum amount of grass each patch can own

  food-scale         ;; range for the amount of food above the minimum each goat can hold
  food-min           ;; the minimum amount of food each goat can store
    
  bite-size-scale    ;; range for the amount of grass above the minimum each goat can eat with each bite
  bite-size-min      ;; the minimum amount of food each goat can eat with each bite
    
  colors             ;; list that holds the colors used for students' turtles
  color-names        ;; list that holds the names of the colors used for students' turtles
  num-colors         ;; number of colors in the color list
  used-colors        ;; list that holds the shape-color pairs that are already being used

  n/a                ;; unset variable indicator
  
  ;; quick start instructions variables
  quick-start        ;; current quickstart instruction displayed in the quickstart monitor
  qs-item            ;; index of the current quickstart instruction
  qs-items           ;; list of quickstart instructions

  grass-max          ;; grass capacity
  food-max           ;; grass collection capacity 
  bite-size          ;; amount of grass collected at each move
]

patches-own [
  grass-stored       ;; amount of grass currently stored
]

breeds [
  goats              ;; creation controlled by farmers
  farmers            ;; created and controlled by clients
]

goats-own [
  food-stored        ;; amount of grass collected from grazing
  owner#             ;; the user-id of the farmer who owns the goat
]

farmers-own [
  user-id            ;; unique user-id, input by the client when they log in, to identify each student turtle
  num-goats-to-buy   ;; desired quantity of goats to purchase
  received-rank?     ;; if given a rank, ranked? is true, otherwise false 
  rank               ;; rank number according to total revenue
  revenue-lst        ;; list of each days' revenue collection
  total-revenue      ;; cumulative revenue
  current-revenue    ;; each day's revenue collected
]


;;;;;;;;;;;;;;;;;;;;;
;; Setup Functions ;;
;;;;;;;;;;;;;;;;;;;;;

to startup
  setup-quick-start
  hubnet-set-client-interface "COMPUTER" [ "models/HubNet Computer Activities/Unverified/clients/Tragedy Commons client.nlogo" ]
  hubnet-reset
  setup
end

;; initializes the display and 
;; set parameters for the system
to setup
  cg
  cc
  reset
end

;; initializes the display 
;; but does not clear already created farmers 
to reset
  setup-globals
  setup-patches
  clear-all-plots
  ask farmers
  [ reset-farmers-vars ]
  hubnet-broadcast "Goat Seller Says:" "Everyone starts with " + init-num-goats/farmer + " goats."
  hubnet-broadcast "num-goats-to-buy" 1
  broadcast-system-info
end

;; initialize global variables
to setup-globals 
  set clock 0
  set day 0
  
  set grass-scale 50
  set grass-min 10
    
  set food-scale 50
  set food-min 50

  set bite-size-min  round (food-min / (grazing-period - 1))
  set bite-size-scale (round ((food-scale + food-min) / (grazing-period - 1)))

  set grass-max grass-scale
  set food-max food-scale
  set bite-size bite-size-scale
  
  set colors      [ white   gray   orange   brown   yellow  turquoise
                    cyan   sky   blue   violet   magenta   pink ]
  set color-names ["white" "gray" "orange" "brown" "yellow" "turquoise"
                   "cyan" "sky" "blue" "violet" "magenta" "pink"]
  set used-colors []
  set num-colors length colors
  set n/a "n/a"
end

;; initialize grass supply for each patch
to setup-patches 
  ask patches
  [
    ;;set amt of food at each patch
    ;set grass-max (randomize grass-min grass-scale)
    set grass-stored grass-max
    color-patches
  ]
end

;; give the user some information about what the setup button does so they can 
;; know whether they want to proceed before actually doing the setup
to setup-prompt
  if user-yes-or-no ("The SETUP button should only be used when starting "
              + "over with a new group (such as a new set of students) since "
              + "all data is lost.  Use the RE-RUN button for continuing with "
              + "an existing group."
              + "\n\nDo you really want to setup the model?")
  [
    user-message "Before closing this dialog, please do the following:"
                 + "\n  -Have everyone that is currently logged in, log off and "
                 + "then kick all remianing clients with the HubNet Console."
    setup
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;
;; Runtime Functions ;;
;;;;;;;;;;;;;;;;;;;;;;;

to go
  every .1
  [
    ;; increment clock
    set clock clock + 1
  
    ;; get command and data from client
    listen-to-clients
    every .5
    [
      broadcast-system-info
    ]
  
    if not any farmers
    [
      user-message "There are no farmers.  GO is stopping.  Press GO again when people have logged in."
      stop
    ]
  
    ;; when not milking time
    ifelse (clock mod grazing-period) != 0 
    [
      ask goats
      [ graze ]
    ]
    [
      set day day + 1
      ask farmers
      [ milk-goats ]
      go-to-market ;; to buy goats
      if show-rank?
      [ rank-farmers ]
      plot-graph
    ]

    reset-patches
  ]
end

;; goat move along the common looking for best patch of grass
to graze  ;; goat procedure 
  locals [ new-food-amt ]
  if (food-stored != food-max) or (other-goats-here = nobody)
  [
    set new-food-amt (food-stored + get-amt-eaten)
    ifelse (new-food-amt < food-max)
    [ set food-stored new-food-amt ]
    [ set food-stored food-max ]
  ]
  rt (random 90)
  lt (random 90)
  fd 1
end

;; returns amount of grass eaten at patch and
;; sets the patch grass amount accordingly
to-report get-amt-eaten  ;; goat procedure
  locals [ reduced-amt ]
  set reduced-amt (grass-stored - bite-size)
  ifelse (reduced-amt < 0) 
  [
    set grass-stored 0
    report grass-stored
  ]
  [
    set grass-stored reduced-amt
    report bite-size
  ]
end

;; collect milk and sells them at market ($1 = 1 gallon)
to milk-goats  ;; farmer procedure
  set current-revenue (round-to-place (sum values-from my-goats [food-stored]) 10)
  ask my-goats
  [ set food-stored 0 ]
  set revenue-lst (fput current-revenue revenue-lst)
  set total-revenue total-revenue + current-revenue
  send-personal-info
end

;; the goat market setup
to go-to-market
  ask farmers with [ num-goats-to-buy > 0 ] 
  [ buy-goats num-goats-to-buy ]
  ask farmers with [ num-goats-to-buy = 0 ]
  [ hubnet-send user-id "Goat Seller Says:" "You did not buy any goats." ]
  ask farmers
  [
    send-personal-info
  ]
end

;; farmers buy goats at market
to buy-goats [ num-goats-desired ]  ;; farmer procecdure
  locals
  [
    num-goats-afford
    cost-of-purchase
    got-number-desired?
    num-goats-purchase
  ]
  set got-number-desired? true
  set num-goats-afford (int (total-revenue / cost/goat))
  set num-goats-purchase num-goats-desired
  if (num-goats-afford < num-goats-purchase) 
  [
    set num-goats-purchase num-goats-afford
    set got-number-desired? false
  ]
  set cost-of-purchase num-goats-purchase * cost/goat
  set total-revenue (total-revenue - cost-of-purchase)
  hubnet-send user-id "Goat Seller Says:"  (seller-says got-number-desired? num-goats-desired num-goats-purchase)

  ;; create the goats purchased by the farmer
  hatch num-goats-purchase
  [ setup-goats user-id ]
end

;; reports the appropriate information on the transaction of purchasing goats
to-report seller-says [ success? desired purchased ]
  locals
  [
    seller-message
    cost
  ]
  set cost purchased * cost/goat
  ifelse success?
  [
    ifelse (purchased > 1)
    [ set seller-message "Here are your " + purchased + " goats.  " ]
    [ set seller-message "Here is your goat.  " ]
    set seller-message seller-message + "You have spent $" + cost + "."
  ]
  [
    set seller-message "You do not have enough to buy " + desired + ".  " 
        + "You can afford " + purchased + " for $" + cost + "."
  ]
  report seller-message
end

;; initializes goat variables
to setup-goats [ farmer# ]  ;; turtle procedure
  set breed goats
  setxy (random screen-size-x) (random screen-size-y)
  set shape "goat-shape"
  set food-stored 0
  ;set food-max (randomize food-min food-scale)
  set owner# farmer#
  st
end

;; ranks farmers by their total revenue
to rank-farmers
  locals
  [ 
    num-tied
    num-ranks
    min-rev
    rankee
    rank#
  ]
  set num-ranks (length (remove-duplicates (values-from farmers [total-revenue])))
  set rank# count farmers
  repeat num-ranks
  [
    set min-rev min values-from farmers with [not received-rank?][total-revenue]
    set rankee farmers with [total-revenue = min-rev]
    set num-tied count rankee
    ask rankee
    [
      set rank rank#
      set received-rank? true
    ]
    set rank# rank# - num-tied
  ] 
  ask farmers
  [ set received-rank? false ]
end


;; updates patches' color and increase grass supply with growth rate
to reset-patches
  locals [ new-grass-amt ]
  ask patches with [grass-stored < grass-max]
  [
    set new-grass-amt (grass-stored + grass-growth-rate)
    ifelse (new-grass-amt > grass-max)
    [ set grass-stored grass-max ]
    [ set grass-stored new-grass-amt ]
    color-patches
  ]
end

;; colors patches according to amount of grass on the patch
to color-patches  ;; patch procedure
  set pcolor (scale-color green grass-stored -5 (2 * grass-scale))
end


;;;;;;;;;;;;;;;;;;;;;;;;
;; Plotting Functions ;;
;;;;;;;;;;;;;;;;;;;;;;;;

;; plots the graph of the system
to plot-graph
  plot-value "Milk Supply" milk-supply
  plot-value "Grass Supply" grass-supply 
  plot-value "Goat Population" goat-population
  plot-value "Average Revenue" avg-revenue/farmer
end

;; plot value on the plot called name-of-plot
to plot-value [ name-of-plot value ]
  set-current-plot name-of-plot
  plot value
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Calculation Functions ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report milk-supply
  report sum values-from farmers [ current-revenue ]
end

to-report grass-supply
  report sum values-from patches [ grass-stored ]
end

to-report goat-population
  report count goats
end

to-report avg-revenue/farmer
  report mean values-from farmers [ current-revenue ]
end

to-report avg-revenue/goat  ;; farmer procedure
  report current-revenue / my-goat-population
end

to-report my-goat-population  ;; farmer procedure
  report count my-goats
end

;; returns agentset that of goats of a particular farmer
to-report my-goats  ;; farmer procedure
  report goats with [ owner# = user-id-of myself ]
end

;; random number generator with min number and range
to-report randomize [ minimum range ]
  report (minimum + (random range))
end

;; rounds given number to certain decimal-place
to-report round-to-place [ num decimal-place ]
  report (round (num * decimal-place)) / decimal-place
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Quick Start functions ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; instructions to quickly setup the model, and clients to run this activity
to setup-quick-start
  set qs-item 0
  set qs-items
  [
    "Teacher: Follow these directions to run the HubNet activity."
      "Optional: Zoom In (see Tools in the Menu Bar)"
      "Optional: Change any of the settings...."
      "If you do change the settings, press the SETUP button."
      "Press the INITIAL LOGIN button to allow people to login."
    "Everyone: Open up a HubNet Client on your machine and..."
        "input the IP Address of this computer press ENTER and..."
        "type your user name in the box and press ENTER."
    "Teacher: Once everyone has logged in,..."
        "turn off the INITIAL LOGIN button by pressing it again."
      "Have the students acquaint themselves with the information..."
        "available to them in the monitors, buttons, and sliders."
      "Then press the GO NetLogo button to start the simulation."
      "Please note that you may adjust the length of time, GRAZING-PERIOD,..."
        "that goats allowed to graze as well as the length of time for..."
        "buying goats, TIME-LIMIT-TO-BUY."
      "For a quicker demonstration, minimized the..."
        "GRASS-GROWTH-RATE slider."
      "To curb buying incentives of the students, either increase..."
        "the ENTRANCE-FEE or COST/GOAT sliders."
      "Any of the above mentioned parameters - ..."
        "GRAZING-PERIOD, GRASS-GROWTH-RATE, TIME-LIMIT-TO-BUY,..."
        "ENTRANCE-FEE, and COST/GOAT -..."
        "may be altered without stopping the simulation."
    
    "Teacher: To rerun the activity with the same group,..."
        "stop the model by pressing the NetLogo GO button, if it is on."
        "Change any of the settings that you would like."
      "Press the NetLogo RE-RUN button."
    "Teacher: Restart the simulation by pressing the NetLogo GO button again."
    
    "Teacher: To start the simulation over with a new group,..."
        "stop the model by pressing the NetLogo GO button, if it is on..."
        "and follow these instructions again from the beginning."
  ]
  set quick-start (item qs-item qs-items)
end

;; view the next item in the quickstart monitor
to view-next
  set qs-item qs-item + 1
  if qs-item >= length qs-items
  [ set qs-item length qs-items - 1 ]
  set quick-start (item qs-item qs-items)
end

;; view the previous item in the quickstart monitor
to view-prev
  set qs-item qs-item - 1
  if qs-item < 0
  [ set qs-item 0 ]
  set quick-start (item qs-item qs-items)
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Code for interacting with the clients ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; determines which client sent a command, and what the command was
to listen-to-clients
  while [ hubnet-message-waiting? ]
  [
    hubnet-fetch-message
    ifelse hubnet-enter-message?
    [
      create-new-farmer hubnet-message-source
    ]
    [
      ifelse hubnet-exit-message?
      [
        remove-farmer hubnet-message-source
      ]
      [ execute-command hubnet-message-tag ]
    ]
  ]
end

;; NetLogo knows what each student turtle is supposed to be
;; doing based on the tag sent by the node:
;; num-goat-to-buy - determine quantity of student's desired purchase
;; buy goats - allows turtel to buy goats of desired quantity
to execute-command [command]
  if command = "num-goats-to-buy"
  [
    ask farmers with [ user-id = hubnet-message-source ]
    [ set num-goats-to-buy hubnet-message ]
    stop
  ]
end

to create-new-farmer [ id ]
  create-custom-farmers 1
  [
    set user-id id
    setup-farm
    set-unique-color
    reset-farmers-vars
    send-system-info
  ]
end

;; situates the farmer in particular location
to setup-farm  ;; farmer procedure
  setxy ((random (screen-size-x - 2)) - screen-edge-x + 1) 
        ((random (screen-size-y - 2)) - screen-edge-y + 1)
  ht
end

;; pick a color for the turtle
to set-unique-color  ;; turtle procedure
  locals [code]
  set code random num-colors
  while[ member? code used-colors and count farmers < num-colors ]
  [ set code random num-colors ]
  set used-colors (lput code used-colors)
  set color item code colors
end

;; set farmer variables to initial values
to reset-farmers-vars  ;; farmer procedure
  ;; reset the farmer variable to initial values
  set revenue-lst []
  set rank n/a
  set received-rank? false
  set num-goats-to-buy 1
  set total-revenue cost/goat
  set current-revenue 0

  ;; get rid of existing goats
  ask my-goats
  [ die ]

  ;; create new goats for the farmer
  hatch init-num-goats/farmer
  [ setup-goats user-id ]

  send-personal-info
end

;; sends the appropriate monitor information back to the client
to send-personal-info  ;; farmer proecdure
  hubnet-send user-id "Your Goat Color is:" (color->string color)
  hubnet-send user-id "Current Revenue" current-revenue
  hubnet-send user-id "Total Revenue" total-revenue
  hubnet-send user-id "My Goat Population" my-goat-population
  hubnet-send user-id "Rank" rank
end

;; returns string version of color name
to-report color->string [ color-value ]
  report item (position color-value colors) color-names
end

;; sends the appropriate monitor information back to one client
to send-system-info  ;; farmer procedure
  hubnet-send user-id "Time Left to Buy" n/a
  hubnet-send user-id "Milk Amt" milk-supply
  hubnet-send user-id "Goat Pop" goat-population
  hubnet-send user-id "Grass Amt" grass-supply
  hubnet-send user-id "Cost per Goat" cost/goat  
  hubnet-send user-id "Day" day
end

;; broadcasts the appropriate monitor information back to all clients
to broadcast-system-info
  hubnet-broadcast "Time Left to Buy" n/a
  hubnet-broadcast "Milk Amt" milk-supply
  hubnet-broadcast "Goat Pop" goat-population
  hubnet-broadcast "Grass Amt" (int grass-supply)
  hubnet-broadcast "Cost per Goat" cost/goat  
  hubnet-broadcast "Day" day
end

;; delete farmers once client has exited
to remove-farmer [ id ]
  locals [ old-color ]
  ask farmers with [user-id = id]
  [
    set old-color color
    ask my-goats
    [ die ]
    die
  ]
  if not any farmers with [ color = old-color ]
  [ set used-colors remove (position old-color colors) used-colors ]
end


; *** NetLogo Model Copyright Notice ***
;
; This activity and associated models and materials was created as part of the projects:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN CLASSROOMS and 
; INTEGRATED SIMULATION AND MODELING ENVIRONMENT.
; These projects gratefully acknowledge the support of the 
; National Science Foundation (REPP & ROLE programs) -- grant numbers 
; REC #9814682 and REC-0126227.
;
; Copyright 2002 by Uri Wilensky. Updated 2003. All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from the copyright holders.
; Contact the copyright holders for appropriate licenses for redistribution 
; for profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2002).  NetLogo HubNet Tragedy of the Commons model.
; http://ccl.northwestern.edu/netlogo/models/HubNetTragedyOfTheCommons.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
462
96
1018
673
10
10
26.0
1
12
0
0

CC-WINDOW
16
557
449
671
Command Center

BUTTON
66
20
159
53
Setup
setup-prompt
NIL
1
T
OBSERVER

BUTTON
366
20
459
53
Go
go
T
1
T
OBSERVER

SLIDER
6
64
198
97
Init-Num-Goats/Farmer
Init-Num-Goats/Farmer
0
10
4
1
1
goats

SLIDER
6
100
198
133
Grass-Growth-Rate
Grass-Growth-Rate
0
2
0.5
0.1
1
oz/cycle

SLIDER
6
136
198
169
Cost/Goat
Cost/Goat
0
2000
893
1
1
$

MONITOR
239
345
337
394
Avg-Rev/Farmer
avg-revenue/farmer
1
1

PLOT
233
174
448
342
Average Revenue
Day
Revenue
0.0
20.0
0.0
1000.0
true
false
PENS
"revenue" 1.0 0 -16777216 true

PLOT
233
398
448
556
Goat Population
Day
Goats 
0.0
20.0
0.0
100.0
true
false
PENS
"num-goats" 1.0 0 -16777216 true

MONITOR
341
345
441
394
Goat Population
goat-population
0
1

MONITOR
42
345
118
394
Milk Supply
milk-supply
0
1

PLOT
15
174
229
342
Milk Supply
Day
Milk (Gallons)
0.0
20.0
0.0
100.0
true
false
PENS
"milk-amt" 1.0 0 -16777216 true

PLOT
15
398
229
556
Grass Supply
Day
Grass (lbs)
0.0
20.0
0.0
100.0
true
false
PENS
"grass-amt" 1.0 0 -16777216 true

SWITCH
336
64
456
97
Show-Rank?
Show-Rank?
0
1
-1000

SLIDER
203
100
332
133
Grazing-Period
Grazing-Period
0
50
34
1
1
NIL

MONITOR
121
345
207
394
Grass Supply
grass-supply
0
1

BUTTON
166
20
255
53
Re-Run
reset
NIL
1
T
OBSERVER

MONITOR
6
10
63
59
Day
Day
3
1

BUTTON
462
61
580
94
Reset Instructions
setup-quick-start
NIL
1
T
OBSERVER

BUTTON
798
61
882
94
NEXT >>>
view-next
NIL
1
T
OBSERVER

BUTTON
720
61
798
94
<<< PREV
view-prev
NIL
1
T
OBSERVER

MONITOR
462
10
882
59
Quick Start Instructions- More in Info Window
quick-start
0
1

BUTTON
259
20
363
53
Initial Login
listen-to-clients
T
1
T
OBSERVER

@#$#@#$#@
WHAT IS IT?
-----------
This model simulates the utilization of a common good or resource by multiple users.  In this example, the common resource is represented by the common grazing area, utilized by goat farmers for feeding their goats.  Depending on the actions of the participants, the outcome may demonstrate a phenomenon called the "tragedy of the commons", where a common good or resource is over-utilized.

This is a counterexample to the efficient (as defined in "Pareto efficiency") market theorem.  (The efficient market theorem states that agents, looking out for their own best interest [i.e., everyone trying to increase their own wealth], leads to the most efficient social outcome [i.e., the highest quantity of milk].)

This activity uses Tragedy Commons client.nlogo for the HubNet Client interface.


HOW IT WORKS
------------
The students act as the farmers.  They own INIT-NUM-GOATS/FARMER when they join the simulation.

The goats move around the screen for a time span of GRAZING-PERIOD to graze and feed themselves.  The amount of grass they eat is equivalent to how much milk they can produce (and ultimately, the amount of profit they produce for the farmer).

After the GRAZING-PERIOD, the farmers may choose to buy more goats to increase their own wealth.

Initially, the abundance of GRASS-SUPPLY of the patches can sustain the goats and their grazing and leads to increasing milk-supply and increasing revenue.  But suppose, then, that due to the farmers' own incentive to increase their own wealth and each farmer's indifference to the other farmers' decision to purchase goats, each farmer continues to buy more goats.  With the increase of the GOAT-POPULATION, GRASS-SUPPLY gradually decreases.  Ultimately, the common grazing area does not contain enough grass to sustain the overcrowding of goats, and the milk-supply as well as the farmers' revenues decline.  This is the "tragedy of the commons".


HOW TO USE IT
-------------
QUICKSTART INSTRUCTIONS:
------------------------
Teacher: Follow these directions to run the HubNet activity.
Optional: Zoom In (see Tools in the Menu Bar)
Optional: Change any of the settings.  If you do change the settings, press the SETUP button.
Press the INITIAL LOGIN button to allow people to login.
Everyone: Open up a HubNet Client on your machine and input the IP Address of this computer press ENTER and type your user name in the box and press ENTER.

Teacher: Once everyone has logged in, turn off the INITIAL LOGIN button by pressing it again.
Have the students view their interface window to acquaint themselves with the various information available to them in the monitors, buttons, and sliders.
Then press the GO NetLogo button to start the simulation.  

Teacher: Please note that you may adjust the length of time, GRAZING-PERIOD, that goats allowed to graze as well as the length of time for buying goats, TIME-LIMIT-TO-BUY.  For a quicker demonstration, minimized the GRASS-GROWTH-RATE slider.
To curb buying incentives of the students, either increase the ENTRANCE-FEE or COST/GOAT sliders.
Any of the above mentioned parameters - GRAZING-PERIOD, GRASS-GROWTH-RATE, TIME-LIMIT-TO-BUY, ENTRANCE-FEE, and COST/GOAT - may be altered without stopping the simulation. 
    
Teacher: To rerun the activity with the same group, stop the model by pressing the NetLogo GO button, if it is on.
Change any of the settings you like.
Press the NetLogo RE-RUN button.
Restart the simulation by pressing the NetLogo GO button.  
    
Teacher: To start the simulation over with a new group, stop the model by pressing the NetLogo GO button, if it is on and follow these instructions again from the beginning.

BUTTONS:
--------
SETUP - clears all turtles and patches and the plot.  This should only be pressed when starting out with a new group of users since all data is lost.
RE-RUN - sets up the model to be ready for another trial of the simulation with the same group
INITIAL LOGIN - allows users to log into the activity without running the model or collecting data
GO - runs the simulation

SLIDERS:
--------
INIT-NUM-GOATS/FARMER - initial number of goats per farmer at the beginning of the simulation
GRASS-GROWTH-RATE - amount of grass growth for each tick of the clock
COST/GOAT - cost for a goat
TIME-LIMIT-TO-BUY - window of time, allotted for farmers to buy additional goats
GRAZING-PERIOD - the time frame in which goats are allowed to graze
ENTRANCE-FEE - sets the one-time fee needed to allow their goats to graze in the commons

SWITCHES:
---------
SHOW-RANK? - when on, ranks the farmers by their total revenue.  When off, ranks are not revealed.
SHOW-GOAT# - when on, labels each goat by the farmer's user-id for identification.  When off, labels are hidden.

MONITORS:
---------
GRASS SUPPLY - amount of grass available to eat
MILK SUPPLY - amount of milk produced each day
AVG-PROFIT/DAY - amount of revenue collected from milk sale per day
GOAT POPULATION - number of goats grazing in the common area

PLOTS:
------
GRASS SUPPLY - reveals amount of grass available to graze upon vs. day
MILK SUPPLY - reveals amount of milk produced vs. day
AVERAGE REVENUE - reveals average revenue of all farmers vs. day
GOAT POPULATION - reveals number of goats on grazing field vs. day


CLIENT INFORMATION
------------------
After logging in, the client interface will appear for the students, and if GO is pressed in NetLogo, they will be assigned a farmer which will be described by the color in the YOUR GOAT COLOR IS: monitor.  The MY GOAT POPULATION monitor will display the number of goats each student owns.  Their revenue tally for each day will be displayed in the CURRENT REVENUE and their total revenue tally - in the TOTAL REVENUE monitor. 

The global variables of the Cost per Goat and Entrance Fee can be viewed on COST/GOAT and FEE monitors.  The performance of the society, measured by the goat population, amount of grass available for food, and the amount of milk produced, can be measured from the GOAT POP, GRASS AMT, and MILK AMT, respectively.  The current day, a day being defined as one milking session, is displayed in the DAY monitor. 

The student controls the purchase of his/her future goat population.  Only a window of time, determined by TIME-LIMIT-TO-BUY slider in NetLogo, is allotted for the student to make the decision to buy a goat and the quantity of goats to buy.  To buy goats, the student must adjust NUM-GOATS-TO-BUY slider to his/her desired quantity, then press the BUY-GOAT button.  This action must be executed, in the allotted time, which will be displayed and counted down in the TIME-LEFT-TO-BUY monitor.  The transaction of the purchase will be described in the GOAT SELLER SAYS: monitor, which will inform the client of the action taken and how many goats were purchased, if any.

The students can observe their own progress in the RANK monitor, which ranks the student according to their TOTAL REVENUE.  The progress of the community's welfare as measured by the grass available for grazing, the goat population, average revenue of farmers, and milk supply are charted in the GRASS SUPPLY, GOAT POPULATION, AVERAGE REVENUE, MILK SUPPLY plots (respectively), which are identical to the plot of the same name in NetLogo.


THINGS TO NOTICE
----------------
Note that if the students do not confer with each other, the tragedy of the common arises.  The general pattern of the plot for average revenue and milk supply are similar -- the curves eventually peak and are followed by a decrease.  After, the initial run, ask the students which parameters helped them to decide to purchase or not purchase goats.  Ask the students to switch objectives for the simulation; instead of maximizing total-revenue, ask them to maximize milk-supply.  Also, ask the students to confer and act as cooperative unit.


THINGS TO TRY
-------------
Use the model with the entire class to serve as an introduction to the topic.  Upon running the initial set of simulations, ask the students to switch objective - instead of maximizing total-revenue, ask them to maximize milk-supply for the entire community.  Ask the students to confer and act as a cooperative unit.  Observe and discuss the changes in AVG-REV/FARMER and MILK-SUPPLY from the initial simulation and the later simulation with altered objectives.  Continue forth to discuss how the "Tragedy of the Commons" can be avoided and why or why not a society would want to avoid this phenomenon.  Then, have students use the NetLogo model individually, in a computer lab, to explore the effects of the various parameters.  Discuss what they find, observe, and can conclude from this model.


EXTENDING THE MODEL
-------------------
Currently, the goats cannot be discarded, once purchased.  How would having the option to sell or discard the goats help in avoiding the tragedy?  Even with this option, will the students still refrain from doing so?  From what other phenomena (e.g. prisoner's dilemma or free-rider problem) would the student's behavior to not sell the goats arise (if it arises)?


CREDITS AND REFERENCES
----------------------
This activity and associated models and materials was created as part of the projects: PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN CLASSROOMS and INTEGRATED SIMULATION AND MODELING ENVIRONMENT. These projects gratefully acknowledge the support of the National Science Foundation (REPP & ROLE programs) -- grant numbers REC #9814682 and REC-0126227.

Copyright 2002 by Uri Wilensky. Updated 2003. All rights reserved.

Permission to use, modify or redistribute this model is hereby granted, provided that both of the following requirements are followed:
a) this copyright notice is included.
b) this model will not be redistributed for profit without permission from the copyright holders.
Contact the copyright holders for appropriate licenses for redistribution for profit.

To refer to this model in academic publications, please use: Wilensky, U. (2002). NetLogo HubNet Tragedy of the Commons model. http://ccl.northwestern.edu/netlogo/models/HubNetTragedyOfTheCommons. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150
Polygon -7566196 true true 270 14
Polygon -7566196 true true 276 21

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -256 true false 151 152 137 77 105 67 89 67 66 74 48 85 36 100 24 116 14 134 0 151 15 167 22 182 40 206 58 220 82 226 105 226 134 222
Polygon -16777216 true false 151 150 149 128 149 114 155 98 178 80 197 80 217 81 233 95 242 117 246 141 247 151 245 177 234 195 218 207 206 211 184 211 161 204 151 189 148 171
Polygon -7566196 true true 246 151 241 119 240 96 250 81 261 78 275 87 282 103 277 115 287 121 299 150 286 180 277 189 283 197 281 210 270 222 256 222 243 212 242 192
Polygon -16777216 true false 115 70 129 74 128 223 114 224
Polygon -16777216 true false 89 67 74 71 74 224 89 225 89 67
Polygon -16777216 true false 43 91 31 106 31 195 45 211
Line -1 false 200 144 213 70
Line -1 false 213 70 213 45
Line -1 false 214 45 203 26
Line -1 false 204 26 185 22
Line -1 false 185 22 170 25
Line -1 false 169 26 159 37
Line -1 false 159 37 156 55
Line -1 false 157 55 199 143
Line -1 false 200 141 162 227
Line -1 false 162 227 163 241
Line -1 false 163 241 171 249
Line -1 false 171 249 190 254
Line -1 false 192 253 203 248
Line -1 false 205 249 218 235
Line -1 false 218 235 200 144

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

goat-shape
false
0
Polygon -7566196 true true 97 116 125 128 166 130 209 119 243 136 244 171 231 188 215 193 215 243 205 244 203 192 169 182 131 185 130 245 116 245 115 184 87 138
Polygon -7566196 true true 243 146 260 152 259 180 253 155
Polygon -7566196 true true 97 113 82 93 61 93 34 134 43 145 59 137 79 133 86 138
Polygon -7566196 true true 58 136 65 150 55 161 58 146
Rectangle -7566196 true true 88 123 103 138
Rectangle -7566196 true true 88 120 100 133
Rectangle -7566196 true true 88 119 100 131
Rectangle -7566196 true true 86 119 95 123
Rectangle -7566196 true true 88 115 98 124
Rectangle -7566196 true true 87 134 90 140
Polygon -6524078 true false 69 91 76 65 114 57 120 68 109 64 83 71 80 93
Polygon -7566196 true true 203 193 201 242 204 243
Polygon -7566196 true true 205 217 201 242 205 242
Polygon -7566196 true true 105 168 81 186 90 223 101 222 94 188 118 183
Polygon -7566196 true true 184 186 173 197 186 223 196 213 183 196
Polygon -6524078 true false 68 92 82 92

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 46 130
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 1.3beta1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
